@@ -31,9 +31,12 @@ ContextBase::ContextBase()
   _writeCount(false),
   _writeOverlap(false),
   _writeAllOverlap(false),
-  _haveFraction(false),
-  _overlapFraction(1E-9),
-  _reciprocal(false),
+  _haveFractionA(false),
+  _haveFractionB(false),
+  _overlapFractionA(0.0),
+  _overlapFractionB(0.0),
+  _reciprocalFraction(false),
+  _eitherFraction(false),
   _sameStrand(false),
   _diffStrand(false),
   _sortedInput(false),
@@ -52,17 +55,36 @@ ContextBase::ContextBase()
   _seed(0),
   _forwardOnly(false),
   _reverseOnly(false),
+  _nameCheckDisabled(false),
   _hasColumnOpsMethods(false),
   _keyListOps(NULL),
   _desiredStrand(FileRecordMergeMgr::ANY_STRAND),
   _maxDistance(0),
-  _useMergedIntervals(false)
+  _useMergedIntervals(false),
+  _reportPrecision(-1),
+  _splitBlockInfo(NULL),
+  _allFilesHaveChrInChromNames(UNTESTED),
+  _allFileHaveLeadingZeroInChromNames(UNTESTED),
+  _noEnforceCoordSort(false),
+  _inheader(false),
+  _nameConventionWarningTripped(false)
 
 {
 	_programNames["intersect"] = INTERSECT;
 	_programNames["sample"] = SAMPLE;
 	_programNames["map"] = MAP;
 	_programNames["merge"] = MERGE;
+	_programNames["closest"] = CLOSEST;
+	_programNames["subtract"] = SUBTRACT;
+	_programNames["jaccard"] = JACCARD;
+	_programNames["spacing"] = SPACING;
+	_programNames["fisher"] = FISHER;
+	_programNames["sample"] = SAMPLE;
+	_programNames["coverage"] = COVERAGE;
+	_programNames["complement"] = COMPLEMENT;
+	_programNames["groupby"] = GROUP_BY;
+
+
 
 	if (hasColumnOpsMethods()) {
 		_keyListOps = new KeyListOps();
@@ -74,6 +96,14 @@ ContextBase::~ContextBase()
 	delete _genomeFile;
 	_genomeFile = NULL;
 
+	delete _splitBlockInfo;
+	_splitBlockInfo = NULL;
+
+	if (_nameConventionWarningTripped) {
+		cerr << _nameConventionWarningMsg << endl;
+	}
+
+
 	//close all files and delete FRM objects.
 	for (int i=0; i < (int)_files.size(); i++) {
 		_files[i]->close();
@@ -84,7 +114,6 @@ ContextBase::~ContextBase()
 		delete _keyListOps;
 		_keyListOps = NULL;
 	}
-
 }
 
 bool ContextBase::determineOutputType() {
@@ -123,18 +152,24 @@ void ContextBase::openGenomeFile(const BamTools::RefVector &refVector)
 	_genomeFile = new NewGenomeFile(refVector);
 }
 
-bool ContextBase::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
+bool ContextBase::testCmdArgs(int argc, char **argv) {
 	_argc = argc;
 	_argv = argv;
-	_skipFirstArgs = skipFirstArgs;
-	if (_argc < 2) {
-		setShowHelp(true);
+	_skipFirstArgs = 1;
+	setProgram(_programNames[argv[0]]);
+	_argsProcessed.resize(_argc - _skipFirstArgs, false);
+
+	if (!parseCmdArgs(argc, argv, 1) || getShowHelp() || !isValidState()) {
+		if (!_errorMsg.empty()) {
+			cerr <<_errorMsg << endl;
+		}
 		return false;
 	}
+	return true;
+}
 
-	setProgram(_programNames[argv[0]]);
+bool ContextBase::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
 
-	_argsProcessed.resize(_argc - _skipFirstArgs, false);
 
 	for (_i=_skipFirstArgs; _i < argc; _i++) {
 		if (isUsed(_i - _skipFirstArgs)) {
@@ -171,6 +206,9 @@ bool ContextBase::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
         else if (strcmp(_argv[_i], "-iobuf") == 0) {
 			if (!handle_iobuf()) return false;
         }
+        else if (strcmp(_argv[_i], "-prec") == 0) {
+			if (!handle_prec()) return false;
+        }
         else if (strcmp(_argv[_i], "-header") == 0) {
 			if (!handle_header()) return false;
         }
@@ -195,6 +233,9 @@ bool ContextBase::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
         else if (strcmp(_argv[_i], "-sortout") == 0) {
 			if (!handle_sortout()) return false;
         }
+        else if (strcmp(_argv[_i], "-nonamecheck") == 0) {
+			if (!handle_nonamecheck()) return false;
+        }
 
 	}
 	return true;
@@ -211,15 +252,36 @@ bool ContextBase::isValidState()
 	if (!determineOutputType()) {
 		return false;
 	}
+	if (_program != GROUP_BY && _files[0]->getRecordType() == FileRecordTypeChecker::NO_POS_PLUS_RECORD_TYPE) {
+		_errorMsg = "ERROR: file ";
+		_errorMsg.append(_files[0]->getFileName());
+		_errorMsg.append(" has non positional records, which are only valid for the groupBy tool.");
+		return false;
+	}
+	if (getObeySplits()) {
+		_splitBlockInfo = new BlockMgr(_overlapFractionA, _reciprocalFraction);
+	}
 	if (hasColumnOpsMethods()) {
 
-		//TBD: Adjust column ops for multiple databases.
-		//For now, use last file.
-//		FileRecordMgr *dbFile = getFile(hasIntersectMethods() ? _databaseFileIdx : 0);
-		FileRecordMgr *dbFile = getFile(getNumInputFiles()-1);
-		_keyListOps->setDBfileType(dbFile->getFileType());
-		if (!_keyListOps->isValidColumnOps(dbFile)) {
-			return false;
+		if (hasIntersectMethods()) {
+			for (int i=0; i < (int)_dbFileIdxs.size(); i++) {
+				FileRecordMgr *dbFile = getFile(_dbFileIdxs[i]);
+				_keyListOps->setDBfileType(dbFile->getFileType());
+				if (!_keyListOps->isValidColumnOps(dbFile)) {
+					return false;
+				}
+			}
+		} else {
+			FileRecordMgr *dbFile = getFile(0);
+			_keyListOps->setDBfileType(dbFile->getFileType());
+			if (!_keyListOps->isValidColumnOps(dbFile)) {
+				return false;
+			}
+		}
+		//if user specified a precision, pass it to
+		//keyList ops
+		if (_reportPrecision != -1) {
+			_keyListOps->setPrecision(_reportPrecision);
 		}
 	}
 	return true;
@@ -269,9 +331,12 @@ bool ContextBase::openFiles() {
 		frm->setFullBamFlags(_useFullBamTags);
 		frm->setIsSorted(_sortedInput);
 		frm->setIoBufSize(_ioBufSize);
-		if (!frm->open()) {
+		if (!frm->open(_inheader)) {
 			return false;
 		}
+		if (_noEnforceCoordSort) {
+			frm->setNoEnforceCoodSort(true);
+		}
 		_files[i] = frm;
 	}
 	_allFilesOpened = true;
@@ -412,7 +477,7 @@ bool ContextBase::handle_seed()
 bool ContextBase::handle_split()
 {
     setObeySplits(true);
-    markUsed(_i - _skipFirstArgs);
+     markUsed(_i - _skipFirstArgs);
 	return true;
 }
 
@@ -460,10 +525,33 @@ bool ContextBase::handle_o()
         markUsed(_i - _skipFirstArgs);
         _i++;
         markUsed(_i - _skipFirstArgs);
+        return true;
     }
-    return true;
+    return false;
 }
 
+bool ContextBase::handle_prec()
+{
+	if (!hasColumnOpsMethods()) {
+		return false;
+	}
+    if ((_i+1) < _argc) {
+    	int prec = atoi(_argv[_i + 1]);
+    	if (prec < 1) {
+    		_errorMsg += "\n***** ERROR: -prec must be followed by a positive integer. Exiting. *****";
+    		return false;
+    	}
+    	 _reportPrecision = prec;
+        markUsed(_i - _skipFirstArgs);
+        _i++;
+        markUsed(_i - _skipFirstArgs);
+        return true;
+    }
+	_errorMsg += "\n***** ERROR: -prec must be followed by a positive integer. Exiting. *****";
+    return false;
+}
+
+
 
 // for col ops, -null is a NULL value assigned
 // when no overlaps are detected.
@@ -487,6 +575,7 @@ bool ContextBase::handle_null()
 bool ContextBase::handle_delim()
 {
 	if (!hasColumnOpsMethods()) {
+		_errorMsg = "\n***** ERROR: Can't set delimiter for tools without column operations. Exiting. *****";
 		return false;
 	}
     if ((_i+1) < _argc) {
@@ -505,6 +594,13 @@ bool ContextBase::handle_sortout()
 	return true;
 }
 
+bool ContextBase::handle_nonamecheck()
+{
+	setNameCheckDisabled(true);
+	markUsed(_i - _skipFirstArgs);
+	return true;
+}
+
 void ContextBase::setColumnOpsMethods(bool val)
 {
 	if (val && !_hasColumnOpsMethods) {
@@ -572,3 +668,106 @@ bool ContextBase::parseIoBufSize(QuickString bufStr)
 	}
 	return true;
 }
+
+void ContextBase::testNameConventions(const Record *record) {
+	//Do nothing if using the -nonamecheck option,
+	//warning already given, or record is unmapped BAM record
+	if (getNameCheckDisabled() || _nameConventionWarningTripped || record->isUnmapped()) return;
+
+	int fileIdx = record->getFileIdx();
+
+	//
+	// First test whether chr in chrom names match
+	//
+
+	bool hasChr = record->hasChrInChromName();
+	testType testChrVal = fileHasChrInChromNames(fileIdx);
+
+	if (testChrVal == UNTESTED) {
+		_fileHasChrInChromNames[fileIdx] = hasChr ? YES : NO;
+	}
+	if ((_allFilesHaveChrInChromNames == YES && !hasChr) || (_allFilesHaveChrInChromNames == NO && hasChr)) {
+		nameConventionWarning(record, _fileNames[fileIdx], " has inconsistent naming convention for record:\n");
+	}
+
+	if (_allFilesHaveChrInChromNames == UNTESTED) {
+		_allFilesHaveChrInChromNames = hasChr ? YES : NO;
+	}
+
+
+	//
+	// Now test whether leading zero in chrom names match
+	//
+
+
+	bool zeroVal = record->hasLeadingZeroInChromName(hasChr);
+	testChrVal = fileHasLeadingZeroInChromNames(fileIdx);
+	if (testChrVal == UNTESTED) {
+		_fileHasLeadingZeroInChromNames[fileIdx] = zeroVal ? YES : NO;
+	}
+	if ((_allFileHaveLeadingZeroInChromNames == YES && !zeroVal) || (_allFileHaveLeadingZeroInChromNames == NO && zeroVal)) {
+		nameConventionWarning(record, _fileNames[fileIdx], " has a record where naming convention (leading zero) is inconsistent with other files:\n");
+	}
+
+	if (_allFileHaveLeadingZeroInChromNames == UNTESTED) {
+		_allFileHaveLeadingZeroInChromNames = zeroVal ? YES : NO;
+	}
+}
+
+ContextBase::testType ContextBase::fileHasChrInChromNames(int fileIdx) {
+	conventionType::iterator iter = _fileHasChrInChromNames.find(fileIdx);
+	if (iter == _fileHasChrInChromNames.end()) {
+		return UNTESTED;
+	}
+	return iter->second;
+}
+
+ContextBase::testType ContextBase::fileHasLeadingZeroInChromNames(int fileIdx) {
+	conventionType::iterator iter = _fileHasLeadingZeroInChromNames.find(fileIdx);
+	if (iter == _fileHasLeadingZeroInChromNames.end()) {
+		return UNTESTED;
+	}
+	return iter->second;
+}
+
+
+
+void ContextBase::warn(const Record *record, const QuickString str1, const QuickString str2, const QuickString str3) {
+	QuickString msg;
+	setErrorMsg(msg, true, record, str1, str2, str3);
+	cerr << msg << endl;
+}
+
+void ContextBase::die(const Record *record, const QuickString str1, const QuickString str2, const QuickString str3) {
+	QuickString msg;
+	setErrorMsg(msg, false, record, str1, str2, str3);
+	cerr << msg << endl;
+	exit(1);
+}
+
+void ContextBase::setErrorMsg(QuickString &msg, bool onlyWarn, const Record * record, QuickString str1, const QuickString str2, const QuickString str3) {
+	if (onlyWarn) {
+		msg = "\n***** WARNING: ";
+	} else {
+		msg = "\n***** ERROR: ";
+	}
+	msg.append(str1);
+	msg.append(str2);
+	msg.append(str3);
+	msg.append(" Exiting...\n");
+	if (record != NULL) {
+		record->print(msg);
+	}
+}
+
+void ContextBase::nameConventionWarning(const Record *record, const QuickString &filename, const QuickString &message)
+{
+	 _nameConventionWarningMsg = "***** WARNING: File ";
+	 _nameConventionWarningMsg.append(filename);
+	 _nameConventionWarningMsg.append(message);
+	 record->print(_nameConventionWarningMsg);
+	 _nameConventionWarningMsg.append("\n");
+	 _nameConventionWarningTripped = true;
+
+	 cerr << _nameConventionWarningMsg << endl;
+}
