@@ -38,7 +38,7 @@ public:
 	typedef enum {UNSPECIFIED_PROGRAM, INTERSECT, WINDOW, CLOSEST, COVERAGE, MAP, GENOMECOV, MERGE, CLUSTER,
 		COMPLEMENT, SUBTRACT, SLOP, FLANK, SORT, RANDOM, SAMPLE, SHUFFLE, ANNOTATE, MULTIINTER, UNIONBEDG, PAIRTOBED,
 		PAIRTOPAIR,BAMTOBED, BEDTOBAM, BEDTOFASTQ, BEDPETOBAM, BED12TOBED6, GETFASTA, MASKFASTA, NUC,
-		MULTICOV, TAG, JACCARD, OVERLAP, IGV, LINKS,MAKEWINDOWS, GROUPBY, EXPAND } PROGRAM_TYPE;
+		MULTICOV, TAG, JACCARD, OVERLAP, IGV, LINKS,MAKEWINDOWS, GROUPBY, EXPAND, SPACING, FISHER, GROUP_BY} PROGRAM_TYPE;
 
 	PROGRAM_TYPE getProgram() const { return _program; }
 	FileRecordMgr *getFile(int fileIdx) { return _files[fileIdx]; }
@@ -69,7 +69,8 @@ public:
 	void setOutputFileType(ContextFileType fileType) { _outputFileType = fileType; }
 	ContextFileType getOutputFileType() const { return _outputFileType; }
 
-	virtual bool parseCmdArgs(int argc, char **argv, int skipFirstArgs);
+	virtual bool testCmdArgs(int argc, char **argv);
+	virtual bool errorEncountered() const { return !_errorMsg.empty(); }
 
 	 //isValidState checks that parameters to context are in an acceptable state.
 	// If not, the error msg string will be set with a reason why it failed.
@@ -116,6 +117,8 @@ public:
     virtual bool getUseFullBamTags() const { return _useFullBamTags; }
     virtual void setUseFullBamTags(bool val) { _useFullBamTags = val; }
 
+    virtual bool getNameCheckDisabled() const { return _nameCheckDisabled; }
+    virtual void setNameCheckDisabled(bool val) { _nameCheckDisabled = val; }
 
 	// METHODS FOR PROGRAMS WITH USER_SPECIFIED NUMBER
 	// OF OUTPUT RECORDS.
@@ -143,6 +146,11 @@ public:
     virtual bool hasColumnOpsMethods() const { return _hasColumnOpsMethods; }
     const QuickString &getColumnOpsVal(RecordKeyVector &keyList) const;
     //methods applicable only to column operations.
+    int getReportPrecision() const { return _reportPrecision; }
+
+
+    void testNameConventions(const Record *);
+    BlockMgr *getSplitBlockInfo() { return _splitBlockInfo; }
 
 protected:
 	PROGRAM_TYPE _program;
@@ -177,9 +185,12 @@ protected:
     bool _writeCount;
     bool _writeOverlap;
     bool _writeAllOverlap;
-    bool _haveFraction;
-    float _overlapFraction;
-    bool _reciprocal;
+    bool _haveFractionA;
+    bool _haveFractionB;
+    float _overlapFractionA;
+    float _overlapFractionB;
+    bool _reciprocalFraction;
+    bool _eitherFraction;
     bool _sameStrand;
     bool _diffStrand;
     bool _sortedInput;
@@ -203,6 +214,7 @@ protected:
 	int _seed;
 	bool _forwardOnly;
 	bool _reverseOnly;
+	bool _nameCheckDisabled;
 
 	//Members for column operations
 	bool _hasColumnOpsMethods;
@@ -214,11 +226,14 @@ protected:
 	int _maxDistance;
 	bool _useMergedIntervals;
 
+	int _reportPrecision; //used in fields reported from numeric ops from map and merge.
+
 
 	void markUsed(int i) { _argsProcessed[i] = true; }
 	bool isUsed(int i) const { return _argsProcessed[i]; }
+	virtual bool parseCmdArgs(int argc, char **argv, int skipFirstArgs);
 	bool cmdArgsValid();
-	bool openFiles();
+	virtual bool openFiles();
 	virtual FileRecordMgr *getNewFRM(const QuickString &filename, int fileIdx);
 
 	//set cmd line params and counter, i, as members so code
@@ -227,9 +242,26 @@ protected:
 	char **_argv;
 	int _i;
 
-	static const int MIN_ALLOWED_BUF_SIZE = 8;
+	//track whether each file has the letters chr in their chrom names.
+	//this is needed for enforcing consistent naming conventions across
+	//multiple files, and auto-detecting errors when they're not followed.
+	typedef enum { YES, NO, UNTESTED } testType;
+	typedef map<int, testType> conventionType;
+	conventionType _fileHasChrInChromNames;
+	// as above, but check whether first digit to appear in
+	// a chrom name is a zero.
+	conventionType _fileHasLeadingZeroInChromNames;
 
-	virtual bool handle_bed();
+	static const int MIN_ALLOWED_BUF_SIZE = 8;
+	BlockMgr *_splitBlockInfo;
+
+    testType _allFilesHaveChrInChromNames;
+    testType _allFileHaveLeadingZeroInChromNames;
+    bool _noEnforceCoordSort;
+	bool _inheader;
+
+
+    virtual bool handle_bed();
 	virtual bool handle_fbam();
 	virtual bool handle_g();
 	virtual bool handle_h();
@@ -249,9 +281,28 @@ protected:
 	virtual bool handle_null();
 	virtual bool handle_delim();
 	virtual bool handle_sortout();
-
+	virtual bool handle_nonamecheck();
+	bool handle_prec();
 	bool parseIoBufSize(QuickString bufStr);
 
+    testType fileHasChrInChromNames(int fileIdx);
+    testType fileHasLeadingZeroInChromNames(int fileIdx);
+
+    void setNoEnforceCoordSort(bool val) { _noEnforceCoordSort = val; }
+    //Warning messages.
+   bool _nameConventionWarningTripped;
+   QuickString _nameConventionWarningMsg;
+   void nameConventionWarning(const Record *record, const QuickString &filename, const QuickString &message);
+
+    //give warning but continue.
+    void warn(const Record *, const QuickString str1, const QuickString str2 = "", const QuickString str3 = "");
+    // Give error and exit.
+    void die(const Record *, const QuickString str1, const QuickString str2 = "", const QuickString str3 = "");
+
+    //private error handler
+    void setErrorMsg(QuickString &msg, bool onlyWarn, const Record * record, QuickString str1, const QuickString str2, const QuickString str3);
+
+
 };
 
 #endif /* CONTEXTBASE_H_ */
