@@ -19,18 +19,6 @@ ContextIntersect::~ContextIntersect()
 
 
 bool ContextIntersect::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
-	_argc = argc;
-	_argv = argv;
-	_skipFirstArgs = skipFirstArgs;
-	if (_argc < 2) {
-		setShowHelp(true);
-		return false;
-	}
-
-	setProgram(_programNames[argv[0]]);
-
-	_argsProcessed.resize(_argc - _skipFirstArgs, false);
-
 	for (_i=_skipFirstArgs; _i < argc; _i++) {
 		if (isUsed(_i - _skipFirstArgs)) {
 			continue;
@@ -56,6 +44,9 @@ bool ContextIntersect::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
         else if (strcmp(_argv[_i], "-f") == 0) {
 			if (!handle_f()) return false;
         }
+        else if (strcmp(_argv[_i], "-F") == 0) {
+			if (!handle_F()) return false;
+        }
         else if (strcmp(_argv[_i], "-wa") == 0) {
 			if (!handle_wa()) return false;
         }
@@ -74,6 +65,9 @@ bool ContextIntersect::parseCmdArgs(int argc, char **argv, int skipFirstArgs) {
         else if(strcmp(_argv[_i], "-r") == 0) {
 			if (!handle_r()) return false;
         }
+        else if(strcmp(_argv[_i], "-e") == 0) {
+			if (!handle_e()) return false;
+        }
         else if (strcmp(_argv[_i], "-v") == 0) {
 			if (!handle_v()) return false;
         }
@@ -119,6 +113,23 @@ bool ContextIntersect::isValidState()
 			return false;
 		}
 	}
+
+	if (_haveFractionA && (_overlapFractionA <= 0.0 || _overlapFractionA > 1.0)) {
+		_errorMsg = "\n***** ERROR: -f must be in the range (0.0, 1.0]. *****";
+		return false;
+	}
+	if (_haveFractionB && (_overlapFractionB <= 0.0 || _overlapFractionB > 1.0)) {
+		_errorMsg = "\n***** ERROR: -F must be in the range (0.0, 1.0]. *****";
+		return false;
+	}
+	if (_haveFractionB && !_haveFractionA && _eitherFraction) {
+		_errorMsg = "\n***** ERROR: -e must be used with -f. *****";
+		return false;
+	}
+	if (_haveFractionB && _reciprocalFraction) {
+		_errorMsg = "\n***** ERROR: -r must be used with -f. *****";
+		return false;
+	}
 	if (getUseDBnameTags() && _dbNameTags.size() != _dbFileIdxs.size()) {
 		_errorMsg = "\n***** ERROR: Number of database name tags given does not match number of databases. *****";
 		return false;
@@ -274,8 +285,20 @@ bool ContextIntersect::handle_c()
 bool ContextIntersect::handle_f()
 {
     if ((_i+1) < _argc) {
-        setHaveFraction(true);
-        setOverlapFraction(atof(_argv[_i + 1]));
+        setHaveFractionA(true);
+        setOverlapFractionA(atof(_argv[_i + 1]));
+        markUsed(_i - _skipFirstArgs);
+        _i++;
+        markUsed(_i - _skipFirstArgs);
+    }
+    return true;
+}
+
+bool ContextIntersect::handle_F()
+{
+    if ((_i+1) < _argc) {
+        setHaveFractionB(true);
+        setOverlapFractionB(atof(_argv[_i + 1]));
         markUsed(_i - _skipFirstArgs);
         _i++;
         markUsed(_i - _skipFirstArgs);
@@ -292,7 +315,14 @@ bool ContextIntersect::handle_loj()
 
 bool ContextIntersect::handle_r()
 {
-	setReciprocal(true);
+	setReciprocalFraction(true);
+	markUsed(_i - _skipFirstArgs);
+    return true;
+}
+
+bool ContextIntersect::handle_e()
+{
+	setEitherFraction(true);
 	markUsed(_i - _skipFirstArgs);
     return true;
 }
@@ -353,4 +383,3 @@ bool ContextIntersect::handle_wo()
 	markUsed(_i - _skipFirstArgs);
     return true;
 }
-
