@@ -8,13 +8,15 @@
 #ifndef SINGLELINETEXTFILEREADER_H_
 #define SINGLELINETEXTFILEREADER_H_
 
-using namespace std;
-
 #include "FileReader.h"
 #include "QuickString.h"
 
 class SingleLineDelimTextFileReader : public FileReader {
 public:
+	//Allow VCF records to access a specialized private method.
+	//See end of class declaration for details.
+	friend class VcfRecord;
+
 	SingleLineDelimTextFileReader(int numFields, char delimChar = '\t');
 	~SingleLineDelimTextFileReader();
 
@@ -26,6 +28,8 @@ public:
 	virtual void appendField(int fieldNum, QuickString &str) const;
 	virtual const QuickString &getHeader() const { return _header; }
 	virtual bool hasHeader() const { return _fullHeaderFound; }
+	virtual void setInHeader(bool val) { _inheader = val; }
+
 protected:
 	int _numFields;
 	char _delimChar;
@@ -37,9 +41,16 @@ protected:
 	QuickString _currChromStr;
 	QuickString _tempChrPosStr;
 	int _lineNum;
+	bool _inheader;
 	bool detectAndHandleHeader();
 	bool findDelimiters();
 
+	//This is actually a very specialized function strictly for VCF
+	//records to read and process extra information about Structural Variants.
+	static const int VCF_TAG_FIELD = 7;
+	int getVcfSVlen();
+
+
 };
 
 
