@@ -25,8 +25,9 @@ FileRecordMgr::FileRecordMgr(const QuickString &filename)
   _bamReader(NULL),
   _hasGenomeFile(false),
   _genomeFile(NULL),
-  _ioBufSize(0)
-{
+  _ioBufSize(0),
+  _noEnforceCoordSort(false)
+ {
 }
 
 FileRecordMgr::~FileRecordMgr(){
@@ -42,8 +43,10 @@ FileRecordMgr::~FileRecordMgr(){
 	_recordMgr = NULL;
 }
 
-bool FileRecordMgr::open(){
+bool FileRecordMgr::open(bool inheader){
 	_bufStreamMgr = new BufferedStreamMgr(_filename);
+	_bufStreamMgr->getTypeChecker().setInHeader(inheader);
+
 	if (_ioBufSize > 0) _bufStreamMgr->setIoBufSize(_ioBufSize);
 	if (!_bufStreamMgr->init()) {
 		cerr << "Error: unable to open file or unable to determine types for file " << _filename << endl;
@@ -60,7 +63,7 @@ bool FileRecordMgr::open(){
 		_bufStreamMgr = NULL;
 		exit(1);
 	}
-	allocateFileReader();
+	allocateFileReader(inheader);
 	_recordMgr = new RecordMgr(_recordType, _freeListBlockSize);
 
 	_fileReader->setFileName(_filename.c_str());
@@ -109,14 +112,14 @@ Record *FileRecordMgr::getNextRecord(RecordKeyVector *keyList)
 	// but still return it so the -v (noHit) option and the like will still
 	// see it.
 
-	if (!record->isUnmapped()) {
-		if (!record->coordsValid()) {
+	if (!record->isUnmapped() ) {
+		if (!record->coordsValid() && (record->getType() != FileRecordTypeChecker::NO_POS_PLUS_RECORD_TYPE)) {
 			cerr << "Error: Invalid record in file " << _filename << ". Record is " << endl << *record << endl;
 			exit(1);
 		}
 
 		//test for sorted order, if necessary.
-		if (_isSortedInput) {
+		if (_isSortedInput && !_noEnforceCoordSort) {
 			testInputSortOrder(record);
 		}
 	}
@@ -140,12 +143,6 @@ void FileRecordMgr::assignChromId(Record *record) {
 
 void FileRecordMgr::testInputSortOrder(Record *record)
 {
-	// User specified that file must be sorted. Check that it is so.
-	// TBD: In future versions, we might not want/need all files to be sorted,
-	// even if the -sorted option is used, depending on number of input files
-	// and program being run. Should that occur, this block will need adjusting.
-	// NEK - 9/5/13
-
 
 	// Special: For BAM records that aren't mapped, we actually don't want
 	// to test the sort order. Another ugly hack sponsored by the letters B, A, and M.
@@ -207,13 +204,14 @@ void FileRecordMgr::deleteRecord(RecordKeyVector *keyList) {
 	_recordMgr->deleteRecord(keyList->getKey());
 }
 
-void FileRecordMgr::allocateFileReader()
+void FileRecordMgr::allocateFileReader(bool inheader)
 {
 	switch (_fileType) {
 	case FileRecordTypeChecker::EMPTY_FILE_TYPE:
 	case FileRecordTypeChecker::SINGLE_LINE_DELIM_TEXT_FILE_TYPE:
 	case FileRecordTypeChecker::VCF_FILE_TYPE:
 		_fileReader = new SingleLineDelimTextFileReader(_bufStreamMgr->getTypeChecker().getNumFields(), _bufStreamMgr->getTypeChecker().getDelimChar());
+		static_cast<SingleLineDelimTextFileReader *>(_fileReader)->setInHeader(inheader);
 		break;
 
 	case FileRecordTypeChecker::BAM_FILE_TYPE:
