@@ -35,7 +35,7 @@ void BlockMgr::getBlocks(RecordKeyVector &keyList, bool &mustDelete)
 	switch (keyList.getKey()->getType()) {
 	case FileRecordTypeChecker::BED12_RECORD_TYPE:
 		getBlocksFromBed12(keyList, mustDelete);
-		break; //not necessary after return, but here in case code is later modified.
+		break;
 
 	case FileRecordTypeChecker::BAM_RECORD_TYPE:
 		getBlocksFromBam(keyList, mustDelete);
@@ -128,6 +128,12 @@ Record *BlockMgr::allocateAndAssignRecord(const Record *keyRecord, int startPos,
 	record->setChromId(keyRecord->getChromId());
 	record->setStartPos(startPos);
 	record->setEndPos(endPos);
+	QuickString startPosStr;
+	QuickString endPosStr;
+	startPosStr.append(startPos);
+	endPosStr.append(endPos);
+	record->setStartPosStr(startPosStr);
+	record->setEndPosStr(endPosStr);
 	record->setName(keyRecord->getName());
 	record->setScore(keyRecord->getScore());
 	record->setStrand(keyRecord->getStrand());
@@ -168,7 +174,7 @@ int BlockMgr::findBlockedOverlaps(RecordKeyVector &keyList, RecordKeyVector &hit
 		RecordKeyVector hitBlocks(*hitListIter);
 		bool deleteHitBlocks = false;
 		getBlocks(hitBlocks, deleteHitBlocks); //get all blocks for the hit record.
-		int hitBlockSumLength = getTotalBlockLength(hitBlocks); //get total lentgh of the bocks for the hitRecord.
+		int hitBlockSumLength = getTotalBlockLength(hitBlocks); //get total length of the bocks for the hitRecord.
 		int totalHitOverlap = 0;
 		bool hitHasOverlap = false;
 
@@ -189,13 +195,14 @@ int BlockMgr::findBlockedOverlaps(RecordKeyVector &keyList, RecordKeyVector &hit
 
 			}
 		}
-		_overlapBases.push_back(totalHitOverlap);
 		if (hitHasOverlap) {
-			if ((float) totalHitOverlap / (float)keyBlocksSumLength > _overlapFraction) {
+			if ((float) totalHitOverlap / (float)keyBlocksSumLength >= _overlapFraction) {
 				if (_hasReciprocal &&
-						((float)totalHitOverlap / (float)hitBlockSumLength > _overlapFraction)) {
+						((float)totalHitOverlap / (float)hitBlockSumLength >= _overlapFraction)) {
+					_overlapBases.push_back(totalHitOverlap);
 					resultList.push_back(*hitListIter);
 				} else if (!_hasReciprocal) {
+					_overlapBases.push_back(totalHitOverlap);
 					resultList.push_back(*hitListIter);
 				}
 			}
