@@ -122,21 +122,34 @@ bool Record::chromAfter(const Record *other) const
 
 bool Record::after(const Record *other) const
 {
-	return (_chrId == other->_chrId && _startPos >= other->_endPos);
+	return (sameChrom(other) && _startPos >= other->_endPos);
 }
 
 bool Record::intersects(const Record *record,
-			bool wantSameStrand, bool wantDiffStrand, float overlapFraction, bool reciprocal) const
+                        bool sameStrand,
+                        bool diffStrand,
+                        float overlapFractionA,
+                        float overlapFractionB,
+                        bool reciprocalFraction,
+                        bool eitherFraction) const
 {
 	//must be on same chromosome
 	if (!sameChrom(record)) {
 		return false;
 	}
-	return sameChromIntersects(record, wantSameStrand, wantDiffStrand, overlapFraction, reciprocal);
+	return sameChromIntersects(record,
+                               sameStrand, diffStrand,
+                               overlapFractionA, overlapFractionB,
+                               reciprocalFraction, eitherFraction);
 }
 
 bool Record::sameChromIntersects(const Record *record,
-		bool wantSameStrand, bool wantDiffStrand, float overlapFraction, bool reciprocal) const
+                                 bool sameStrand,
+                                 bool diffStrand,
+                                 float overlapFractionA,
+                                 float overlapFractionB,
+                                 bool reciprocalFraction,
+                                 bool eitherFraction) const
 {
 	// Special: For records that are unmapped, intersect should automatically return false
 	if (_isUnmapped || record->isUnmapped()) {
@@ -150,43 +163,57 @@ bool Record::sameChromIntersects(const Record *record,
 	bool isSameStrand = (_strandVal == record->_strandVal && _strandVal != UNKNOWN);
 	bool isDiffStrand = ( _strandVal != UNKNOWN && record->_strandVal != UNKNOWN && _strandVal != record->_strandVal);
 
-	if (wantSameStrand && !isSameStrand) {
+	if (sameStrand && !isSameStrand) {
 		return false; //want same, but they're not same.
 	}
-	if (wantDiffStrand && !isDiffStrand) {
+	if (diffStrand && !isDiffStrand) {
 		return false; //want different, but they're not different.
 	}
 
 	int otherStart = record->getStartPos();
 	int otherEnd = record->getEndPos();
 
+	bool otherZeroLen = (otherStart - otherEnd == 0);
 	int maxStart = max(_startPos, otherStart);
 	int minEnd = min(_endPos, otherEnd);
 
+	bool localZeroLen = (_endPos - _startPos == 0);
 	//rule out all cases of no intersection at all
 	if (minEnd < maxStart) {
 		return false;
 	}
 
 
+	if ((overlapFractionA == 0.0) && (overlapFractionB == 0.0))
+    {
+		//don't care about amount of overlap.
+		//however, if minEnd and maxStart are equal, and
+		//neither record is zeroLen, return false.
+		if (minEnd == maxStart && !otherZeroLen && !localZeroLen) {
+			return false;
+		}
+		return true;
+	}
+
 	int overlapBases = minEnd - maxStart;
-	int len = _endPos - _startPos;
-	int otherLen = otherEnd - otherStart;
+	int aLen = _endPos - _startPos;
+	int bLen = otherEnd - otherStart;
 
-	if ((float)overlapBases / (float)len < overlapFraction) {
-		return false;
-	}
+    float overlapA = (float)overlapBases / (float)aLen;
+    float overlapB = (float)overlapBases / (float)bLen;
 
-	//at this point, we've ruled out strandedness, non-intersection,
-	//and query coverage (overlapFraction). The only thing left is
-	//database coverage.
-	if (!reciprocal) {
-		return true;
-	}
+    bool sufficentFractionA = (overlapA >= overlapFractionA);
+    bool sufficentFractionB = (overlapB >= overlapFractionB);
 
-	if ((float)overlapBases / (float)otherLen >= overlapFraction) {
-		return true;
-	}
+    if (!eitherFraction)
+    {
+        if (sufficentFractionA && sufficentFractionB) { return true; }
+        return false;
+    }
+    else {
+        if (sufficentFractionA || sufficentFractionB) { return true; }
+        return false;
+    }
 
 	return false;
 }
@@ -233,3 +260,34 @@ const QuickString &Record::getField(int fieldNum) const
           << endl << "*****" << endl;
     exit(1);
 }
+
+
+bool Record::hasChrInChromName() const {
+	const char *str = _chrName.c_str();
+	//if the chrom name has at least 3 characters,
+	//and the first 3 are c, h, r, case-insensitive,
+	//return true. Otherwise, return false.
+	return ((_chrName.size() >= 3) &&
+			(str[0] == 'c' || str[0] == 'C') &&
+			(str[1] == 'h' || str[1] == 'H') &&
+			(str[2] == 'r' || str[2] == 'R'));
+}
+
+bool Record::hasLeadingZeroInChromName(bool chrKnown) const {
+	const char *str = _chrName.c_str();
+	// only check to see if the digit zero follows the occurance of
+	// "chr", case insensitive.
+	return (_chrName.size() >= 4 && str[3] == '0' && (chrKnown || hasChrInChromName()));
+}
+
+void Record::print(FILE *fp, bool newline) const {
+	QuickString buf;
+	print(buf);
+	fprintf(fp, "%s", buf.c_str());
+	if(newline) fprintf(fp, "\n");
+}
+
+int Record::getLength(bool obeySplits) const {
+	//only bed12 and BAM need to check splits
+	return _endPos - _startPos;
+}
