@@ -8,19 +8,14 @@
 #ifndef KEYLIST_H_
 #define KEYLIST_H_
 
-
-
-
-using namespace std;
-
 #include "Record.h"
-#include "BTlist.h"
+#include "RecordList.h"
 
 class RecordKeyList {
 public:
 	typedef const Record * elemType;
-	typedef BTlist<elemType> listType;
-	typedef const BTlistNode<elemType> *const_iterator_type;
+	typedef RecordList listType;
+	typedef const RecordListNode *const_iterator_type;
 	RecordKeyList();
     RecordKeyList(elemType item);
     RecordKeyList(elemType item, const listType &list);
@@ -50,6 +45,8 @@ public:
     }
     bool allClear() { return (_key == NULL && empty()); }
 
+    void sort() { _list.sort(); }
+
 
 private:
     elemType _key;
