@@ -25,16 +25,14 @@ public:
 	virtual void printNull(QuickString &outBuf) const;
 	virtual FileRecordTypeChecker::RECORD_TYPE getType() const { return FileRecordTypeChecker::VCF_RECORD_TYPE; }
 
-	//Note: using the assignment operator in a BedPlusInterval can potentially be a performance hit,
-	//if the number of fields frequently differ between this object and the one being copied.
-	const BedPlusInterval &operator=(const VcfRecord &other);
-
 	virtual const QuickString &getField(int fieldNum) const;
+	static bool isNumericField(int fieldNum);
 
 protected:
 	QuickString _varRef;
 	QuickString _varAlt;
-	static const int constPrintStartIdx = 3;
+	static const int numFixedFields = 6;
+
 	void printOtherFields(QuickString &outBuf) const;
 };
 
