@@ -163,7 +163,7 @@ public:
       zeroLength(false)
     {}
     
-    int size() {
+    int size() const {
         return end-start;
     }
 
@@ -380,6 +380,7 @@ public:
 
     // Constructor
     BedFile(string &);
+    BedFile(void);
 
     // Destructor
     ~BedFile(void);
@@ -417,6 +418,10 @@ public:
     // load a BED file into a map keyed by chrom, then bin. value is 
     // vector of BEDs
     void loadBedFileIntoMap();
+    void loadBedFileIntoMergedMap();
+
+    // load a BED entry into and existing map
+    void addBEDIntoMap(BED bedEntry);
 
     // load a BED file into a map keyed by chrom, then bin. value is 
     // vector of BEDCOVs
@@ -429,6 +434,9 @@ public:
     // load a BED file into a map keyed by chrom. value is vector of BEDs
     void loadBedFileIntoMapNoBin();
 
+    // load a BED file into a vector of BEDs
+    void loadBedFileIntoVector();
+
     // Given a chrom, start, end and strand for a single feature,
     // search for all overlapping features in another BED file.
     // Searches through each relevant genome bin on the same chromosome
@@ -461,6 +469,16 @@ public:
     // that the feature overlaps
     void countListHits(const BED &a, int index, 
                        bool sameStrand, bool diffStrand);
+    
+    
+    // return the total length of all the intervals in the file.
+    // use with GetNextBed()
+    unsigned long getTotalLength(void);
+
+    // return the total _flattened_ length of all the intervals in the file.
+    // use with GetNextMergedBed()
+    unsigned long getTotalFlattenedLength(void);
+    
 
     // the bedfile with which this instance is associated
     string bedFile;
@@ -473,6 +491,7 @@ public:
     masterBedCovMap      bedCovMap;
     masterBedCovListMap  bedCovListMap;
     masterBedMap         bedMap;
+    bedVector            bedList;
     masterBedMapNoBin    bedMapNoBin;
     
     BedLineStatus _status;
@@ -498,6 +517,8 @@ private:
     string _merged_chrom;
     int _prev_start;
     string _prev_chrom;
+    unsigned long _total_length;
+    unsigned long _total_flattened_length;
 
     void setZeroBased(bool zeroBased);
     void setGff (bool isGff);
@@ -977,14 +998,14 @@ public:
 
 
     /*
-        reportBedNewLine
+        reportToFileBedNewLine
 
         Writes the _original_ BED entry with a NEWLINE
         at the end of the line.
         Works for BED3 - BED6.
     */
     template <typename T>
-    inline void reportBedNewLine(const T &bed) {
+    inline void reportToFileBedNewLine(FILE* out,const T &bed) {
         
         // if it is azeroLength feature, we need to
         // correct the start and end coords to what they were
@@ -999,24 +1020,24 @@ public:
         //BED
         if (_isGff == false && _isVcf == false) {
             if (this->bedType == 3) {
-                printf ("%s\t%d\t%d\n", bed.chrom.c_str(), start, end);
+                fprintf(out,"%s\t%d\t%d\n", bed.chrom.c_str(), start, end);
             }
             else if (this->bedType == 4) {
-                printf ("%s\t%d\t%d\t%s\n", 
+                fprintf(out,"%s\t%d\t%d\t%s\n", 
                     bed.chrom.c_str(), start, end, bed.name.c_str());
             }
             else if (this->bedType == 5) {
-                printf ("%s\t%d\t%d\t%s\t%s\n", 
+                fprintf(out,"%s\t%d\t%d\t%s\t%s\n", 
                     bed.chrom.c_str(), start, end, 
                     bed.name.c_str(), bed.score.c_str());
             }
             else if (this->bedType == 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s\n", 
+                fprintf(out,"%s\t%d\t%d\t%s\t%s\t%s\n", 
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
             }
             else if (this->bedType > 6) {
-                printf ("%s\t%d\t%d\t%s\t%s\t%s", 
+                fprintf(out,"%s\t%d\t%d\t%s\t%s\t%s", 
                     bed.chrom.c_str(), start, end, bed.name.c_str(),
                     bed.score.c_str(), bed.strand.c_str());
 
@@ -1025,27 +1046,27 @@ public:
                 vector<uint16_t>::const_iterator 
                     othEnd = bed.other_idxs.end();
                 for ( ; othIt != othEnd; ++othIt) {
-                    printf("\t%s", bed.fields[*othIt].c_str());
+                    fprintf(out,"\t%s", bed.fields[*othIt].c_str());
                 }
-                printf("\n");
+                fprintf(out,"\n");
             }
         }
         // VCF
         else if (_isGff == false && _isVcf == true) {
-            printf ("%s\t%d", bed.chrom.c_str(), start+1);
+            fprintf(out,"%s\t%d", bed.chrom.c_str(), start+1);
 
             vector<uint16_t>::const_iterator othIt  = bed.other_idxs.begin();
             vector<uint16_t>::const_iterator othEnd = bed.other_idxs.end();
             for ( ; othIt != othEnd; ++othIt) {
-                printf("\t%s", bed.fields[*othIt].c_str());
+                fprintf(out,"\t%s", bed.fields[*othIt].c_str());
             }
-            printf("\n");
+            fprintf(out,"\n");
         }
         // GFF
         else if (_isGff == true) {
             // "GFF-8"
             if (this->bedType == 8) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\n", 
+                fprintf (out,"%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\n", 
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1053,7 +1074,7 @@ public:
             }
             // "GFF-9"
             else if (this->bedType == 9) {
-                printf ("%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\n", 
+                fprintf (out,"%s\t%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\n", 
                     bed.chrom.c_str(), bed.fields[bed.other_idxs[0]].c_str(),
                     bed.name.c_str(), start+1, end,
                     bed.score.c_str(), bed.strand.c_str(),
@@ -1063,6 +1084,12 @@ public:
         }
     }
 
+    /* specialized version of reportBedNewLine printing to stdout */
+     template <typename T>
+     inline void reportBedNewLine(const T &bed) {
+     reportToFileBedNewLine(stdout,bed);
+     }
+
     /*
         reportBedRangeNewLine
 
